Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1246)

Unified Diff: content/public/browser/javascript_dialog_manager.h

Issue 2412843002: Simplify the JavaScriptDialogManager. (Closed)
Patch Set: braces Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/javascript_dialog_manager.h
diff --git a/content/public/browser/javascript_dialog_manager.h b/content/public/browser/javascript_dialog_manager.h
index 001137b36a620622ea74819c038a7ebecc92f437..fb1fbd1e4da24fd9dd025f85575dc39c891d3003 100644
--- a/content/public/browser/javascript_dialog_manager.h
+++ b/content/public/browser/javascript_dialog_manager.h
@@ -50,11 +50,13 @@ class CONTENT_EXPORT JavaScriptDialogManager {
bool accept,
const base::string16* prompt_override);
- // Cancels all active and pending dialogs for the given WebContents.
- virtual void CancelActiveAndPendingDialogs(WebContents* web_contents) = 0;
-
- // Reset any saved state tied to the given WebContents.
- virtual void ResetDialogState(WebContents* web_contents) = 0;
+ // Cancels all active and pending dialogs for the given WebContents. If
+ // |suppress_callbacks| is true, suppresses the calls to callbacks while
+ // canceling those dialogs. If |reset_state| is true, resets any saved state
+ // tied to |web_contents|.
+ virtual void CancelDialogs(WebContents* web_contents,
+ bool suppress_callbacks,
+ bool reset_state) = 0;
virtual ~JavaScriptDialogManager() {}
};
« no previous file with comments | « content/browser/web_contents/web_contents_impl_unittest.cc ('k') | content/shell/browser/shell_javascript_dialog_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698